@@ -12,6 +12,7 @@
 
 toplevel .xcircuit
 wm title .xcircuit XCircuit
+wm protocol .xcircuit WM_DELETE_WINDOW quit
 
 # This gets rid of the original "wish", in favor of our own window
 
@@ -39,7 +40,7 @@ pack .xcircuit.mainframe.mainarea -expand true -fill both
 
 simple .xcircuit.mainframe.mainarea.sbleft -width 13 -bg beige
 simple .xcircuit.mainframe.mainarea.sbbottom -height 13 -bg beige
-simple .xcircuit.mainframe.mainarea.drawing -bg white
+simple .xcircuit.mainframe.mainarea.drawing -bg white -exitproc "quitnocheck"
 simple .xcircuit.mainframe.mainarea.corner -width 13 -height 13 -bg black
 
 # The drawing area and its scrollbars
@@ -1395,6 +1396,7 @@ $m2 add command -label "Rotate CCW 1" -command {rotate -1}
 set m2 [menu $m.selmenu -tearoff 0]
 $m2 add command -label "Disable selection" -command {element select hide}
 $m2 add command -label "Remove all disabled" -command {element select allow}
+$m2 add separator
 $m2 add check -label "Labels" -variable XCOps(sel_lab) -onvalue true -offvalue false \
 	-command {xcircuit::config filter label $XCOps(sel_lab)}
 $m2 add check -label "Objects" -variable XCOps(sel_obj) -onvalue true -offvalue false \
