@@ -820,7 +820,7 @@ Genericlist *break_up_bus(labelptr blab, objinstptr thisinst, Genericlist *netli
    /* generate	labels "1", "2", etc.					*/
 
    if (buspos == NULL) {
-      Fprintf("Error:  Bus specification has no start delimiter!\n");
+      Fprintf(stderr, "Error:  Bus specification has no start delimiter!\n");
       goto doneBus;
    }
 
@@ -830,7 +830,7 @@ Genericlist *break_up_bus(labelptr blab, objinstptr thisinst, Genericlist *netli
    busend = find_delimiter(buspos);
 
    if (busend == NULL) {
-      Fprintf("Error:  Bus specification has no end delimiter!\n");
+      Fprintf(stderr, "Error:  Bus specification has no end delimiter!\n");
       goto doneBus;
    }
 
