@@ -181,7 +181,7 @@ static XtResource resources[] = {
   { "infolabelcolor", "InfoLabelColor", XtRPixel, sizeof(Pixel),
       XtOffset(ApplicationDataPtr, infocolor), XtRString, "SeaGreen"},
   { "ratsnestcolor", "RatsNestColor", XtRPixel, sizeof(Pixel),
-      XtOffset(ApplicationDataPtr, ratsnestcolor), XtRString, "tan4"},
+      XtOffset(ApplicationDataPtr, ratsnestcolor), XtRString, "Tan4"},
 
   /* non-schematic layout colors */
 
@@ -1991,6 +1991,7 @@ int xc_getlayoutcolor(int cidx)
    XQueryColor(dpy, cmap, &loccolor);
 
    locidx = rgb_alloccolor(loccolor.red, loccolor.green, loccolor.blue);
+   return locidx;
 }
 
 /*-------------------------------------------------------------------------*/
